Module blaxel.core.client.models.sandbox_spec
=============================================

Classes
-------

`SandboxSpec(configurations: blaxel.core.client.types.Unset | ForwardRef('CoreSpecConfigurations') = <blaxel.core.client.types.Unset object>, enabled: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, flavors: blaxel.core.client.types.Unset | list['Flavor'] = <blaxel.core.client.types.Unset object>, integration_connections: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, policies: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, private_clusters: blaxel.core.client.types.Unset | ForwardRef('ModelPrivateCluster') = <blaxel.core.client.types.Unset object>, revision: blaxel.core.client.types.Unset | ForwardRef('RevisionConfiguration') = <blaxel.core.client.types.Unset object>, runtime: blaxel.core.client.types.Unset | ForwardRef('Runtime') = <blaxel.core.client.types.Unset object>, sandbox: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, lifecycle: blaxel.core.client.types.Unset | ForwardRef('SandboxLifecycle') = <blaxel.core.client.types.Unset object>, region: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, volumes: blaxel.core.client.types.Unset | list['VolumeAttachment'] = <blaxel.core.client.types.Unset object>)`
:   Sandbox specification
    
    Attributes:
        configurations (Union[Unset, CoreSpecConfigurations]): Optional configurations for the object
        enabled (Union[Unset, bool]): Enable or disable the resource
        flavors (Union[Unset, list['Flavor']]): Types of hardware available for deployments
        integration_connections (Union[Unset, list[str]]):
        policies (Union[Unset, list[str]]):
        private_clusters (Union[Unset, ModelPrivateCluster]): Private cluster where the model deployment is deployed
        revision (Union[Unset, RevisionConfiguration]): Revision configuration
        runtime (Union[Unset, Runtime]): Set of configurations for a deployment
        sandbox (Union[Unset, bool]): Sandbox mode
        lifecycle (Union[Unset, SandboxLifecycle]): Lifecycle configuration for sandbox management
        region (Union[Unset, str]): Region where the sandbox should be created (e.g. us-pdx-1, eu-lon-1)
        volumes (Union[Unset, list['VolumeAttachment']]):
    
    Method generated by attrs for class SandboxSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `configurations`
    :

    `enabled`
    :

    `flavors`
    :

    `integration_connections`
    :

    `lifecycle`
    :

    `policies`
    :

    `private_clusters`
    :

    `region`
    :

    `revision`
    :

    `runtime`
    :

    `sandbox`
    :

    `volumes`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :